Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(142)

Unified Diff: public/web/WebPluginContainer.h

Issue 967213004: Removed FrameView's windowToContents and contentsToWindow methods. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Rebase Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « public/web/WebFrame.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: public/web/WebPluginContainer.h
diff --git a/public/web/WebPluginContainer.h b/public/web/WebPluginContainer.h
index 50b9ce8ca4d41acebc3c8a082b29023c46251ac6..93026d0a25e5be5240fb9f85dddefeb4e5bfe268 100644
--- a/public/web/WebPluginContainer.h
+++ b/public/web/WebPluginContainer.h
@@ -117,11 +117,11 @@ public:
// is in use but a scroll bar is not in use).
virtual void setWantsWheelEvents(bool) = 0;
- // Converts view's window coordinates to plugin's local coordinates.
- virtual WebPoint windowToLocalPoint(const WebPoint&) = 0;
+ // Converts root frame's coordinates to plugin's local coordinates.
+ virtual WebPoint rootFrameToLocalPoint(const WebPoint&) = 0;
- // Converts plugin's local coordinate to view's window coordinates.
- virtual WebPoint localToWindowPoint(const WebPoint&) = 0;
+ // Converts plugin's local coordinate to root frame's coordinates.
+ virtual WebPoint localToRootFramePoint(const WebPoint&) = 0;
virtual WebPlugin* plugin() = 0;
virtual void setPlugin(WebPlugin*) = 0;
« no previous file with comments | « public/web/WebFrame.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698